import 'package:flutter/material.dart';
import 'package:nb_utils/nb_utils.dart';

enum SymbolType { Bullet, Numbered, Custom }

/// Add UL to its children
class UL extends StatelessWidget {
  final List<Widget>? children;
  final double padding;
  final double spacing;
  final SymbolType symbolType;
  final Color? symbolColor;
  final Color? textColor;
  final Widget? customSymbol;
  final String? prefixText; // Used when SymbolType is Numbered

  UL({
    this.children,
    this.padding = 8,
    this.spacing = 8,
    this.symbolType = SymbolType.Bullet,
    this.symbolColor,
    this.textColor,
    this.customSymbol,
    this.prefixText,
  });

  @override
  Widget build(BuildContext context) {
    return Wrap(
      runSpacing: spacing,
      direction: Axis.horizontal,
      children: children
          .validate()
          .asMap()
          .map((i, element) => MapEntry(
                i,
                Row(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    symbolType == SymbolType.Bullet
                        ? Text(
                            '•',
                            style: boldTextStyle(
                                color: textColor ?? textPrimaryColorGlobal),
                          ).scale(scale: 2.0)
                        : SizedBox(),
                    symbolType == SymbolType.Numbered
                        ? Text('${prefixText.validate()} ${i + 1}.',
                            style: boldTextStyle(
                                color: symbolColor ?? textPrimaryColorGlobal,
                                size: 16))
                        : SizedBox(),
                    (symbolType == SymbolType.Custom && customSymbol != null)
                        ? customSymbol!
                        : SizedBox(),
                    SizedBox(width: padding),
                    element.expand(),
                  ],
                ),
              ))
          .values
          .toList(),
    );
  }
}
